==> zio-aws-ec2_2.13-5.19.8.1-sources.jar: zio/aws/ec2/model/GetAssociatedEnclaveCertificateIamRolesRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.ResourceArn
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetAssociatedEnclaveCertificateIamRolesRequest(
    certificateArn: Optional[ResourceArn] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest = {
    import GetAssociatedEnclaveCertificateIamRolesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest
      .builder()
      .optionallyWith(
        certificateArn.map(value => ResourceArn.unwrap(value): java.lang.String)
      )(_.certificateArn)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest.ReadOnly =
    zio.aws.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest
      .wrap(buildAwsValue())
}
object GetAssociatedEnclaveCertificateIamRolesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest =
      zio.aws.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest(
        certificateArn.map(value => value)
      )
    def certificateArn: Optional[ResourceArn]
    def getCertificateArn: ZIO[Any, AwsError, ResourceArn] =
      AwsError.unwrapOptionField("certificateArn", certificateArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest
  ) extends zio.aws.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest.ReadOnly {
    override val certificateArn: Optional[ResourceArn] = zio.aws.core.internal
      .optionalFromNullable(impl.certificateArn())
      .map(value => zio.aws.ec2.model.primitives.ResourceArn(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest
  ): zio.aws.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-6.20.58.3-sources.jar: zio/aws/ec2/model/GetAssociatedEnclaveCertificateIamRolesRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.CertificateId
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class GetAssociatedEnclaveCertificateIamRolesRequest(
    certificateArn: CertificateId
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest = {
    import GetAssociatedEnclaveCertificateIamRolesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest
      .builder()
      .certificateArn(CertificateId.unwrap(certificateArn): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest.ReadOnly =
    zio.aws.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest
      .wrap(buildAwsValue())
}
object GetAssociatedEnclaveCertificateIamRolesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest =
      zio.aws.ec2.model
        .GetAssociatedEnclaveCertificateIamRolesRequest(certificateArn)
    def certificateArn: CertificateId
    def getCertificateArn: ZIO[Any, Nothing, CertificateId] =
      ZIO.succeed(certificateArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest
  ) extends zio.aws.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest.ReadOnly {
    override val certificateArn: CertificateId =
      zio.aws.ec2.model.primitives.CertificateId(impl.certificateArn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest
  ): zio.aws.ec2.model.GetAssociatedEnclaveCertificateIamRolesRequest.ReadOnly =
    new Wrapper(impl)
}
